package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.BomanReservat;

/**
 * 陵园预约Service接口
 * 
 * @author ruoyi
 * @date 2023-11-02
 */
public interface IBomanReservatService 
{
    /**
     * 查询陵园预约
     * 
     * @param reservatId 陵园预约主键
     * @return 陵园预约
     */
    public BomanReservat selectBomanReservatByReservatId(Long reservatId);

    /**
     * 查询陵园预约列表
     * 
     * @param bomanReservat 陵园预约
     * @return 陵园预约集合
     */
    public List<BomanReservat> selectBomanReservatList(BomanReservat bomanReservat);

    /**
     * 新增陵园预约
     * 
     * @param bomanReservat 陵园预约
     * @return 结果
     */
    public int insertBomanReservat(BomanReservat bomanReservat);

    /**
     * 修改陵园预约
     * 
     * @param bomanReservat 陵园预约
     * @return 结果
     */
    public AjaxResult updateBomanReservat(BomanReservat bomanReservat);

    /**
     * 批量删除陵园预约
     * 
     * @param reservatIds 需要删除的陵园预约主键集合
     * @return 结果
     */
    public int deleteBomanReservatByReservatIds(Long[] reservatIds);

    /**
     * 删除陵园预约信息
     * 
     * @param reservatId 陵园预约主键
     * @return 结果
     */
    public int deleteBomanReservatByReservatId(Long reservatId);

    AjaxResult examine(BomanReservat bomanReservat);

    /**
     * 预约首页统计
     * @param
     * @return
     */
    AjaxResult  indexStatistics (BomanReservat bomanReservat);

    AjaxResult verification(Long reservatId);

    /**
     *  陵园实时参观统计
     *
     * @return
     */
    AjaxResult realTime();

    AjaxResult people();
}
